@@ -1,4 +1,3 @@
-
 #' Container class for parameters to fit the CRM models in trialr.
 #'
 #' @name crm_params-class
@@ -49,9 +48,10 @@
 #' * beta_mean
 #' * beta_sd
 #'
+#' @export
+#'
 #' @seealso
 #' \code{\link{stan_crm}}
-#' \code{\link{crm_process}}
 crm_params <- function(skeleton, target, a0 = NULL,
                        alpha_mean = NULL, alpha_sd = NULL,
                        beta_mean = NULL, beta_sd = NULL,
@@ -68,9 +68,10 @@ crm_params <- function(skeleton, target, a0 = NULL,
                   beta_mean, beta_sd, beta_shape, beta_inverse_scale)
 
   # Initialise with no patients observed
-  x$doses = c()
-  x$tox = c()
   x$num_patients = 0
+  x$doses = integer(length = 0)
+  x$tox = integer(length = 0)
+  x$weights = numeric(length = 0)
 
   # Set type. This is, at heart, just a list.
   class(x) <- c("crm_params", "list")
@@ -114,9 +115,14 @@ crm_params <- function(skeleton, target, a0 = NULL,
 #' @param tox An optional vector of toxicity outcomes for patients
 #' 1:num_patients, where 1=toxicity and 0=no toxicity. Only required when
 #' \code{outcome_str} is not provided.
+#' @param weights An optional vector of numeric weights for the observations
+#' for patients 1:num_patients, thus facilitating the TITE-CRM design.
+#' Can be used with \code{outcome_str}, or with \code{doses_given} and
+#' \code{tox}. It is generally tider to specify \code{doses_given},
+#' \code{tox} and \code{weights} when a TITE-CRM analysis is desired.
 #' @param ... Extra parameters are passed to \code{rstan::sampling}. Commonly
-#' used options are \code{iter}, \code{chains}, \code{warmup}, \code{cores},
-#' \code{control}. \code{\link[rstan:sampling]{sampling}}.
+#' used options are \code{iter}, \code{chains}, \code{warmup}, \code{cores}, and
+#' \code{control}.
 #'
 #' @details
 #' The quickest and easiest way to fit a CRM model to some observed outcomes
@@ -139,7 +145,7 @@ crm_params <- function(skeleton, target, a0 = NULL,
 #' * beta_shape
 #' * beta_inverse_scale
 #'
-#' @section Requirements of \code{logistics} model:
+#' @section Requirements of \code{logistic2} model:
 #' * a0
 #' * alpha_mean
 #' * alpha_sd
@@ -158,22 +164,31 @@ crm_params <- function(skeleton, target, a0 = NULL,
 #'
 #' @seealso
 #'   \code{\link{crm_fit}}
-#'   \code{\link{crm_process}}
+#'   \code{\link[rstan:sampling]{sampling}}.
 #'
 #' @export
 #'
 #' @examples
 #' \dontrun{
-#' # This model is presented in Thall et al. (2014)
+#' # CRM example
 #' mod1 <- stan_crm('1N 2N 3T', skeleton = c(0.1, 0.2, 0.35, 0.6),
 #'                  target = 0.2, model = 'empiric', beta_sd = sqrt(1.34),
 #'                  seed = 123)
 #'
-#' # Shorthand for the above is:
-#' mod2 <- stan_efftox_demo('1N 2E 3B', seed = 123)
+#' mod2 <- stan_crm('1NNN 2NNN 3TTT', skeleton = c(0.1, 0.2, 0.35, 0.6),
+#'                  target = 0.2, model = 'logistic', a0 = 3, beta_mean = 0,
+#'                  beta_sd = sqrt(1.34), seed = 123)
 #'
-#' # the seed is passed to the Stan sampler. The usual Stan sampler params like
+#' # The seed is passed to the Stan sampler. The usual Stan sampler params like
 #' # cores, iter, chains etc are passed on too via the ellipsis operator.
+#'
+#' # TITE-CRM example, p.124 of Dose Finding by the CRM, Cheung (2010)
+#' mod3 <-stan_crm(skeleton = c(0.05, 0.12, 0.25, 0.40, 0.55), target = 0.25,
+#'                 doses_given = c(3, 3, 3, 3),
+#'                 tox = c(0, 0, 0, 0),
+#'                 weights = c(73, 66, 35, 28) / 126,
+#'                 model = 'empiric', beta_sd = sqrt(1.34), seed = 123)
+#' mod3$recommended_dose
 #' }
 stan_crm <- function(outcome_str = NULL, skeleton, target,
                      model = c('empiric', 'logistic', 'logistic_gamma',
@@ -184,6 +199,7 @@ stan_crm <- function(outcome_str = NULL, skeleton, target,
                      beta_shape = NULL, beta_inverse_scale = NULL,
                      doses_given = NULL,
                      tox = NULL,
+                     weights = NULL,
                      ...) {
 
   model <- match.arg(model)
@@ -212,6 +228,7 @@ stan_crm <- function(outcome_str = NULL, skeleton, target,
   if(is.null(outcome_str)) {
     if(length(doses_given) != length(tox))
       stop('doses_given and tox vectors should have same length')
+
     dat$doses <- doses_given
     dat$tox <- tox
     dat$num_patients <- length(doses_given)
@@ -221,6 +238,11 @@ stan_crm <- function(outcome_str = NULL, skeleton, target,
     dat$doses <- outcomes_df$doses
     dat$tox <- outcomes_df$tox
   }
+  # Add weights if specified; infer all to be 1 if not.
+  if(is.null(weights))
+    dat$weights <- rep(1, dat$num_patients)
+  else
+    dat$weights <- weights
 
   # Fit data to model using Stan, after performing model-specific checks.
   if(model == 'empiric') {
@@ -303,9 +325,10 @@ stan_crm <- function(outcome_str = NULL, skeleton, target,
 #' @param fit An object of class \code{\link[rstan:stanfit]{stanfit}},
 #' containing the posterior samples.
 #'
+#' @export
+#'
 #' @seealso
 #' \code{\link{stan_crm}}
-#' \code{\link{crm_process}}
 crm_fit <- function(dose_indices, recommended_dose, prob_tox, median_prob_tox,
                     modal_mtd_candidate, prob_mtd, dat, fit) {
   # crm_fit class
@@ -321,8 +344,8 @@ crm_fit <- function(dose_indices, recommended_dose, prob_tox, median_prob_tox,
 
 #' @title Process RStan samples from a CRM model
 #'
-#' @description Process RStan samples from a CRM model to make inferences
-#' about dose-toxicity and which dose should be recommended next.
+#' @description Internal function to process rstan samples from a CRM model to
+#' make inferences about dose-toxicity and which dose should be recommended next.
 #' Typically, this function is not required to be called explicitly by the user
 #' because \code{\link{stan_crm}} will call it implicitly.
 #'
@@ -331,27 +354,6 @@ crm_fit <- function(dose_indices, recommended_dose, prob_tox, median_prob_tox,
 #' @param fit An instance of \code{rstan::stanmodel}, derived by fitting one of
 #' the trialr CRM models.
 #' @return An instance of \code{\link{crm_fit}}.
-#' @export
-#'
-#' @examples
-#' \dontrun{
-#' dat <- list(
-#'   num_doses = 5,
-#'   skeleton = c(0.05, 0.12, 0.25, 0.40, 0.55),
-#'   target = 0.25,
-#'   beta_sd = sqrt(1.34),
-#'   num_patients = 3,
-#'   doses = c(1, 2, 3),
-#'   tox = c(0, 0, 1)
-#' )
-#' samp <- rstan::sampling(stanmodels$CrmEmpiricNormalPrior,
-#'                         data = dat, seed = 123)
-#' decision <- crm_process(dat, samp)
-#' }
-#'
-#' @seealso
-#' \code{\link{stan_crm}}
-#' \code{\link{crm_params}}
 crm_process <- function(dat, fit) {
   dose_indices <- seq(from = 1, to = dat$num_doses, by = 1)
   # Posterior estimates
@@ -375,17 +377,22 @@ crm_process <- function(dat, fit) {
 #'
 #' @param x \code{\link{crm_fit}} object to convert.
 #' @param ... Extra parameters, passed onwards.
-#' @sdname print
 #' @method print crm_fit
-#' @S3method print crm_fit
+#' @export
 print.crm_fit <- function(x, ...) {
   # Patient-level data
-  treated <- data.frame(
-    Patient = 1:length(x$dat$doses),
-    Dose = x$dat$doses,
-    Toxicity = x$dat$tox
-  )
-  print(treated)
+  if(x$dat$num_patients > 0) {
+    treated <- data.frame(
+      Patient = 1:length(x$dat$doses),
+      Dose = x$dat$doses,
+      Toxicity = x$dat$tox,
+      Weight = x$dat$weights
+    )
+    print(treated)
+
+  } else {
+    cat('No patients have been treated.')
+  }
   cat('\n')
 
   # Dose-level data
@@ -395,9 +402,10 @@ print.crm_fit <- function(x, ...) {
     N = sapply(1:x$dat$num_doses, function(i) sum(x$dat$doses == i)),
     Tox = sapply(1:x$dat$num_doses, function(i) sum(x$dat$tox[x$dat$doses == i])),
     ProbTox = x$prob_tox,
+    MedianProbTox = x$median_prob_tox,
     ProbMTD = x$prob_mtd
   )
-  print(df)
+  print(df, digits = 3)
   cat('\n')
 
   # Extras
@@ -405,7 +413,7 @@ print.crm_fit <- function(x, ...) {
              x$dat$target, '.'))
   cat('\n')
   cat(paste0('The dose with estimated toxicity probability closest to target is ',
-               x$recommended_dose, '.'))
+             x$recommended_dose, '.'))
   cat('\n')
   cat(paste0('The dose most likely to be the MTD is ',
              x$modal_mtd_candidate, '.'))
@@ -417,9 +425,8 @@ print.crm_fit <- function(x, ...) {
 #' @param ... Extra parameters, passed onwards.
 #'
 #' @return A \code{data.frame}
-#' @sdname as.data.frame
 #' @method as.data.frame crm_fit
-#' @S3method as.data.frame crm_fit
+#' @export
 as.data.frame.crm_fit <- function(x, ...) {
   as.data.frame(x$fit, ...)
 }
@@ -431,9 +438,8 @@ as.data.frame.crm_fit <- function(x, ...) {
 #' @param ... Extra parameters, passed onwards.
 #'
 #' @return A plot
-#' @sdname plot
 #' @method plot crm_fit
-#' @S3method plot crm_fit
+#' @export
 plot.crm_fit <- function(x, pars = 'prob_tox', ...) {
   rstan::plot(x$fit, pars = pars, ...)
 }
@@ -444,33 +450,9 @@ plot.crm_fit <- function(x, pars = 'prob_tox', ...) {
 #' @param ... Extra parameters, passed onwards.
 #'
 #' @return A summary object.
-#' @sdname summary
 #' @method summary crm_fit
-#' @S3method summary crm_fit
+#' @export
 summary.crm_fit <- function(object, ...) {
   rstan::summary(object$fit, ...)
 }
 
-
-# Not generic yet.... ----
-# tidybayes is not yet on CRAN but once it is, add it as an import and
-# implement as_sample_tibble.crm_fit(x).
-# However, for now:
-
-#' Extract tall data.frame of posterior prob_tox samples.
-#'
-#' @param x \code{\link{crm_fit}} object.
-#'
-#' @return data.frame
-#' @export
-gather_samples.crm_fit <- function(x) {
-  df <- as.data.frame(x, 'prob_tox')
-  Label <- ProbTox <- NULL
-  df_tall <- df %>%
-    tidyr::gather(Label, ProbTox) %>%
-    dplyr::mutate(
-      DoseLevel = rep(1:ncol(df), each = nrow(df)),
-      Draw = rep(1:nrow(df), times = ncol(df))
-    )
-  df_tall
-}
